==> nextcloud-16.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/gl.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Cargando a vista previa…",
    "Saved" : "Gardado",
    "Admin" : "Administración",
    "a safe home for all your data" : "un lugar seguro para todos os seus datos",
    "Name cannot be empty" : "O nome non pode estar baleiro",
    "The given name is too long" : "O nome indicado é longo de máis",
    "The given web address is too long" : "O enderezo web indicado é longo de máis",
    "The given web address is not a valid URL" : "O enderezo web indicado non é un URL válido",
    "The given legal notice address is too long" : "O enderezo do aviso legal indicado é longo de máis",
    "The given legal notice address is not a valid URL" : "O enderezo do aviso legal indicado non é un URL válido",
    "The given privacy policy address is too long" : "O enderezo da política de privacidade indicado é longo de máis",
    "The given privacy policy address is not a valid URL" : "O enderezo da política de privacidade indicado non é un URL válido",
    "The given slogan is too long" : "O lema indicado é longo de máis",
    "The given color is invalid" : "A cor indicada é incorrecta",
    "The file was uploaded" : "O ficheiro foi enviado",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "O ficheiro enviado excede a directiva indicada por upload_max_filesize de php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "O ficheiro enviado excede da directiva MAX_FILE_SIZE especificada no formulario HTML",
    "The file was only partially uploaded" : "O ficheiro só foi parcialmente enviado",
    "No file was uploaded" : "Non se enviou ningún ficheiro",
    "Missing a temporary folder" : "Falta un cartafol temporal",
    "Could not write file to disk" : "Non foi posíbel escribir o ficheiro no disco",
    "A PHP extension stopped the file upload" : "Unha extensión PHP detivo o envío de ficheiros",
    "No file uploaded" : "Non se enviou ningún ficheiro",
    "Unsupported image type" : "Tipo de imaxe non admitido",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Está a empregar un tema personalizado. Os axustes do aplicativo de temas poden ser sobrescritos por el.",
    "Theming" : "Temas",
    "Legal notice" : "Aviso legal",
    "Privacy policy" : "Política de privacidade",
    "Adjust the Nextcloud theme" : "Axustar o tema do Nextcloud",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Os temas fan posíbel personalizar facilmente a aparencia da súa instancia e os clientes compatíbeis. Isto será visíbel para todos os usuarios.",
    "Name" : "Nome",
    "Reset to default" : "Restabelecer os valores predeterminados",
    "Web link" : "Ligazón web",
    "https://…" : "https://…",
    "Slogan" : "Lema",
    "Color" : "Cor",
    "Logo" : "Logotipo",
    "Upload new logo" : "Enviar un novo logotipo",
    "Login image" : "Imaxe de inicio",
    "Upload new login background" : "Enviar unha nova imaxe de fondo",
    "Remove background image" : "Retirar a imaxe de fondo",
    "Advanced options" : "Opcións avanzadas",
    "Legal notice link" : "Ligazón ao aviso legal",
    "Privacy policy link" : "Ligazón á política de privacidade",
    "Header logo" : "Logotipo da cabeceira",
    "Upload new header logo" : "Enviar un novo logotipo da cabeceira",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Enviar un novo favicon",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instale a extensión de PHP Imagemagick con compatibilidade con imaxes SVG para xerar automáticamente faviconos baseados no logotipo e cor enviados."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-17.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/gl.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Cargando a vista previa…",
    "Saved" : "Gardado",
    "Admin" : "Administración",
    "a safe home for all your data" : "un lugar seguro para todos os seus datos",
    "Name cannot be empty" : "O nome non pode estar baleiro",
    "The given name is too long" : "O nome indicado é longo de máis",
    "The given web address is too long" : "O enderezo web indicado é longo de máis",
    "The given web address is not a valid URL" : "O enderezo web indicado non é un URL válido",
    "The given legal notice address is too long" : "O enderezo do aviso legal indicado é longo de máis",
    "The given legal notice address is not a valid URL" : "O enderezo do aviso legal indicado non é un URL válido",
    "The given privacy policy address is too long" : "O enderezo da política de privacidade indicado é longo de máis",
    "The given privacy policy address is not a valid URL" : "O enderezo da política de privacidade indicado non é un URL válido",
    "The given slogan is too long" : "O lema indicado é longo de máis",
    "The given color is invalid" : "A cor indicada é incorrecta",
    "The file was uploaded" : "O ficheiro foi enviado",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "O ficheiro enviado excede a directiva indicada por upload_max_filesize de php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "O ficheiro enviado excede da directiva MAX_FILE_SIZE especificada no formulario HTML",
    "The file was only partially uploaded" : "O ficheiro só foi parcialmente enviado",
    "No file was uploaded" : "Non se enviou ningún ficheiro",
    "Missing a temporary folder" : "Falta un cartafol temporal",
    "Could not write file to disk" : "Non foi posíbel escribir o ficheiro no disco",
    "A PHP extension stopped the file upload" : "Unha extensión PHP detivo o envío de ficheiros",
    "No file uploaded" : "Non se enviou ningún ficheiro",
    "Unsupported image type" : "Tipo de imaxe non admitido",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Está a empregar un tema personalizado. Os axustes da aplicación de temas poden ser sobrescritos por el.",
    "Theming" : "Temas",
    "Legal notice" : "Aviso legal",
    "Privacy policy" : "Política de privacidade",
    "Adjust the Nextcloud theme" : "Axustar o tema do Nextcloud",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Os temas fan posíbel personalizar facilmente a aparencia da súa instancia e os clientes compatíbeis. Isto será visíbel para todos os usuarios.",
    "Name" : "Nome",
    "Reset to default" : "Restabelecer os valores predeterminados",
    "Web link" : "Ligazón web",
    "https://…" : "https://…",
    "Slogan" : "Lema",
    "Color" : "Cor",
    "Logo" : "Logotipo",
    "Upload new logo" : "Enviar un novo logotipo",
    "Login image" : "Imaxe de inicio",
    "Upload new login background" : "Enviar unha nova imaxe de fondo",
    "Remove background image" : "Retirar a imaxe de fondo",
    "Advanced options" : "Opcións avanzadas",
    "Legal notice link" : "Ligazón ao aviso legal",
    "Privacy policy link" : "Ligazón á política de privacidade",
    "Header logo" : "Logotipo da cabeceira",
    "Upload new header logo" : "Enviar un novo logotipo da cabeceira",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Enviar un novo favicon",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instale a extensión de PHP Imagemagick con compatibilidade con imaxes SVG para xerar automáticamente faviconos baseados no logotipo e cor enviados."
},
"nplurals=2; plural=(n != 1);");
